<?php
defined('ABSPATH') || exit('No direct script access allowed');

class CountDown_woo_widget extends \Elementor\Widget_Base
{

    public function get_name()
    {
        return 'CountDown_woo_widget';
    }

    public function get_title()
    {
        return __('Product CountDown', 'product-countdown');
    }

    public function get_icon()
    {
        return 'eicon-countdown';
    }

    public function get_categories()
    {
        return ['rtl_category'];
    }

    public function get_keywords()
    {
        return ['woocommerce', 'products', 'countdown'];
    }

    public function get_custom_help_url()
    {
        return 'https://rtl.ir';
    }

    public function get_style_depends()
    {
        return ['bootstrap', 'bootstrap-rtl', 'main'];
    }

    public function get_script_depends()
    {
        return ['main'];
    }

    protected function register_controls()
    {

        ############ START CONTENET SECTION CONTROLS ############
        $this->start_controls_section(
            'countdown_rtl_controls',
            [
                'label' => __('Section Content', 'product-countdown'),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );

        // Fetch products on sale
        $sale_products = wc_get_products([
            'status' => 'publish',
            'limit' => -1,
            'meta_query' => [
                [
                    'key' => '_sale_price',
                    'value' => 0,
                    'compare' => '>',
                    'type' => 'NUMERIC'
                ]
            ]
        ]);

        // Prepare options array
        $options = [];
        foreach ($sale_products as $product) {
            $options[$product->get_id()] = $product->get_title();
        }

        //Select product countdown
        $this->add_control(
            'countdown_rtl_select_product',
            [
                'label' => esc_html__('Select Product', 'product-countdown'),
                'type' => \Elementor\Controls_Manager::SELECT2,
                'label_block' => true,
                'multiple' => false,
                'options' => $options,
                'default' => '',
            ]
        );

        //Show and hide discount
        $this->add_control(
            'countdown_rtl_show_discount',
            [
                'label'        => esc_html__('Show Discount', 'product-countdown'),
                'type'         => \Elementor\Controls_Manager::SWITCHER,
                'label_on'     => esc_html__('Show', 'product-countdown'),
                'label_off'    => esc_html__('Hide', 'product-countdown'),
                'return_value' => 'yes',
                'default'      => 'yes',
            ]
        );

        //Show and hide rate
        $this->add_control(
            'countdown_rtl_show_rate',
            [
                'label'        => esc_html__('Show Rate', 'product-countdown'),
                'type'         => \Elementor\Controls_Manager::SWITCHER,
                'label_on'     => esc_html__('Show', 'product-countdown'),
                'label_off'    => esc_html__('Hide', 'product-countdown'),
                'return_value' => 'yes',
                'default'      => 'yes',
            ]
        );

        //Show and hide excerpt
        $this->add_control(
            'countdown_rtl_show_excerpt',
            [
                'label'        => esc_html__('Show Excerpt', 'product-countdown'),
                'type'         => \Elementor\Controls_Manager::SWITCHER,
                'label_on'     => esc_html__('Show', 'product-countdown'),
                'label_off'    => esc_html__('Hide', 'product-countdown'),
                'return_value' => 'yes',
                'default'      => 'yes',
            ]
        );

        //Show and hide Timer
        $this->add_control(
            'countdown_rtl_show_timer',
            [
                'label'        => esc_html__('Show Timer', 'product-countdown'),
                'type'         => \Elementor\Controls_Manager::SWITCHER,
                'label_on'     => esc_html__('Show', 'product-countdown'),
                'label_off'    => esc_html__('Hide', 'product-countdown'),
                'return_value' => 'yes',
                'default'      => 'yes',
            ]
        );

        ############ END CONTENET SECTION CONTROLS ##############
        $this->end_controls_section();


        ############ START STYLE MAIN BOX CONTROLS ############
        $this->start_controls_section(
            'countdown_rtl_style',
            [
                'label' => __('Section Main Box Style', 'product-countdown'),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        //Countdown styles control main box
        $this->add_control(
            'rtl_countdown_style_mainbox',
            [
                'label' => esc_html__('Main Box Styles', 'product-countdown'),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );

        //Countdown Main box background
        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(),
            [
                'name' => 'rtl_countdown_style_mainbox_bg',
                'types' => ['classic', 'gradient', 'video'],
                'selector' => '{{WRAPPER}} .offer-content',
            ]
        );

        //Countdown Main box shadow
        $this->add_group_control(
            \Elementor\Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'rtl_countdown_style_mainbox_shadow',
                'selector' => '{{WRAPPER}} .offer-content',
            ]
        );

        //Countdown Main box border
        $this->add_group_control(
            \Elementor\Group_Control_Border::get_type(),
            [
                'name' => 'rtl_countdown_style_mainbox_border',
                'selector' => '{{WRAPPER}} .offer-content',
            ]
        );

        //Countdown Main box radius
        $this->add_control(
            'rtl_countdown_style_mainbox_radius',
            [
                'label' => esc_html__('Border Radius', 'product-countdown'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em', 'rem', 'custom'],
                'default' => [
                    'top' => 4,
                    'right' => 4,
                    'bottom' => 4,
                    'left' => 4,
                    'unit' => 'px',
                    'isLinked' => true,
                ],
                'selectors' => [
                    '{{WRAPPER}} .offer-content' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        ############ END STYLE MAIN BOX CONTROLS ##############
        $this->end_controls_section();


        ############ START STYLE TITLE BOX CONTROLS ############
        $this->start_controls_section(
            'countdown_rtl_style_title',
            [
                'label' => __('Title Style', 'product-countdown'),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        //Countdown title typo
        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name' => 'countdown_rtl_style_title_typo',
                'selector' => '{{WRAPPER}} .special-offer .offer-content .text h2 a',
            ]
        );

        //Countdown title color
        $this->add_control(
            'countdown_rtl_style_title_color',
            [
                'label'       => esc_html__('Title color', 'product-countdown'),
                'type'     => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .special-offer .offer-content .text h2 a' => 'color: {{VALUE}}',
                ],
            ]
        );

        //Countdown title color hover
        $this->add_control(
            'countdown_rtl_style_title_color_hover',
            [
                'label'       => esc_html__('Title hover color', 'product-countdown'),
                'type'     => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .special-offer .offer-content .text h2 a:hover' => 'color: {{VALUE}}',
                ],
            ]
        );

        ############ END STYLE TITLE BOX CONTROLS ##############
        $this->end_controls_section();


        ############ START STYLE RATE CONTROLS ############
        $this->start_controls_section(
            'countdown_rtl_style_rate',
            [
                'label' => __('Rate Style', 'product-countdown'),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        //Countdown rate typo
        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name' => 'countdown_rtl_style_rate_typo',
                'selector' => '{{WRAPPER}} .rtl_review .rtl_review_item strong.rating',
            ]
        );

        //Countdown rate text color
        $this->add_control(
            'countdown_rtl_style_rate_text_color',
            [
                'label'       => esc_html__('Text color', 'product-countdown'),
                'type'     => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .rtl_review .rtl_review_item strong.rating' => 'color: {{VALUE}}',
                ],
            ]
        );

        //Countdown rate icon color
        $this->add_control(
            'countdown_rtl_style_rate_icon_color',
            [
                'label'       => esc_html__('Icon color', 'product-countdown'),
                'type'     => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .rtl_review .rtl_review_item .star-rating::before' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .rtl_review .rtl_review_item .star-rating span::before' => 'color: {{VALUE}}',
                ],
            ]
        );

        ############ END STYLE RATE CONTROLS ##############
        $this->end_controls_section();


        ############ START STYLE REGULAR PRICE CONTROLS ############
        $this->start_controls_section(
            'countdown_rtl_style_regular_price',
            [
                'label' => __('Regular price Style', 'product-countdown'),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        //Countdown reg price typo
        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name' => 'countdown_rtl_style_reg_price_typo',
                'selector' => '{{WRAPPER}} .special-offer .offer-content .text .price .discount-price',
            ]
        );

        //Countdown reg price color
        $this->add_control(
            'countdown_rtl_style_reg_price_color',
            [
                'label'       => esc_html__('Text color', 'product-countdown'),
                'type'     => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .special-offer .offer-content .text .price .discount-price' => 'color: {{VALUE}}',
                ],
            ]
        );

        ############ END STYLE REGULAR PRICE CONTROLS ##############
        $this->end_controls_section();


        ############ START STYLE SALE PRICE CONTROLS ############
        $this->start_controls_section(
            'countdown_rtl_style_sale_price',
            [
                'label' => __('Sale price Style', 'product-countdown'),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        //Countdown sale price typo
        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name' => 'countdown_rtl_style_sale_price_typo',
                'selector' => '{{WRAPPER}} .special-offer .offer-content .text .price span:first-child',
            ]
        );

        //Countdown sale price color
        $this->add_control(
            'countdown_rtl_style_sale_price_color',
            [
                'label'       => esc_html__('Text color', 'product-countdown'),
                'type'     => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .special-offer .offer-content .text .price span:first-child' => 'color: {{VALUE}}',
                ],
            ]
        );

        ############ END STYLE SALE PRICE CONTROLS ##############
        $this->end_controls_section();


        ############ START STYLE EXCERPT CONTROLS ############
        $this->start_controls_section(
            'countdown_rtl_style_excerpt',
            [
                'label' => __('Excerpt Style', 'product-countdown'),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        //Countdown excerpt typo
        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name' => 'countdown_rtl_style_excerpt_typo',
                'selector' => '{{WRAPPER}} .special-offer .offer-content .text p',
            ]
        );

        //Countdown excerpt color
        $this->add_control(
            'countdown_rtl_style_excerpt_color',
            [
                'label'       => esc_html__('Text color', 'product-countdown'),
                'type'     => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .special-offer .offer-content .text p' => 'color: {{VALUE}}',
                ],
            ]
        );

        //Countdown excerpt alignment
        $this->add_control(
            'countdown_rtl_style_excerpt_align',
            [
                'label' => esc_html__('Alignment', 'product-countdown'),
                'type' => \Elementor\Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' => esc_html__('Left', 'product-countdown'),
                        'icon' => 'eicon-text-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__('Center', 'product-countdown'),
                        'icon' => 'eicon-text-align-center',
                    ],
                    'right' => [
                        'title' => esc_html__('Right', 'product-countdown'),
                        'icon' => 'eicon-text-align-right',
                    ],
                    'justify' => [
                        'title' => esc_html__('Justify', 'product-countdown'),
                        'icon' => 'eicon-text-align-justify',
                    ],
                ],
                'default' => 'right',
                'toggle' => true,
                'selectors' => [
                    '{{WRAPPER}} .special-offer .offer-content .text p' => 'text-align: {{VALUE}};',
                ],
            ]
        );

        ############ END STYLE EXCERPT CONTROLS ##############
        $this->end_controls_section();


        ############ START STYLE TIMER CONTROLS ############
        $this->start_controls_section(
            'countdown_rtl_style_timer',
            [
                'label' => __('Timer Style', 'product-countdown'),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        //Countdown timer number font-size
        $this->add_control(
            'countdown_rtl_style_timer_fontsize',
            [
                'label' => esc_html__('Number size', 'product-countdown'),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => ['px', '%', 'em', 'rem', 'custom'],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                        'step' => 1,
                    ],
                ],
                'default' => [
                    'unit' => 'px',
                    'size' => 20,
                ],
                'selectors' => [
                    '{{WRAPPER}} .special-offer .offer-content .box h1' => 'font-size: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        //Countdown timer number color
        $this->add_control(
            'countdown_rtl_style_timer_number_color',
            [
                'label'       => esc_html__('Number color', 'product-countdown'),
                'type'     => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .special-offer .offer-content .box h1' => 'color: {{VALUE}}',
                ],
            ]
        );

        //Countdown timer title font-size
        $this->add_control(
            'countdown_rtl_style_timer_fontsize_title',
            [
                'label' => esc_html__('Title size', 'product-countdown'),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => ['px', '%', 'em', 'rem', 'custom'],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                        'step' => 1,
                    ],
                ],
                'default' => [
                    'unit' => 'px',
                    'size' => 13,
                ],
                'selectors' => [
                    '{{WRAPPER}} .special-offer .offer-content .box h2' => 'font-size: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        //Countdown timer number color
        $this->add_control(
            'countdown_rtl_style_timer_title_color',
            [
                'label'       => esc_html__('Title color', 'product-countdown'),
                'type'     => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .special-offer .offer-content .box h2' => 'color: {{VALUE}}',
                ],
            ]
        );

        //Countdown timer background
        $this->add_group_control(
			\Elementor\Group_Control_Background::get_type(),
			[
				'name' => 'countdown_rtl_style_timer_bg',
				'types' => [ 'classic', 'gradient', 'video' ],
				'selector' => '{{WRAPPER}} .special-offer .offer-content .box-head',
			]
		);

        //Countdown timer border
        $this->add_group_control(
            \Elementor\Group_Control_Border::get_type(),
            [
                'name'     => 'countdown_rtl_style_timer_border',
                'label'    => esc_html__('Box border', 'product-countdown'),
                'selector' => '{{WRAPPER}} .special-offer .offer-content .box-head',
            ]
        );

        //Countdown timer radius
        $this->add_control(
            'countdown_rtl_style_timer_radius',
            [
                'label' => esc_html__('Border Radius', 'product-countdown'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em', 'rem', 'custom'],
                'default' => [
                    'top' => 4,
                    'right' => 4,
                    'bottom' => 4,
                    'left' => 4,
                    'unit' => 'px',
                    'isLinked' => true,
                ],
                'selectors' => [
                    '{{WRAPPER}} .special-offer .offer-content .box-head' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        ############ END STYLE TIMER CONTROLS ##############
        $this->end_controls_section();
    }

    protected function render()
    {
        $settings = $this->get_settings_for_display();
        $product_id = $settings['countdown_rtl_select_product'];
        get_product_select((int)$product_id, $settings);
    }
}
